@@ -1,7 +1,7 @@
 """
 Type annotations for sts service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sts/type_defs/)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, Sequence
 
-from typing_extensions import NotRequired
-
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
